import { Zoom } from '../graphic/zoom';
import { Mind } from '../index';
import { Anchor as AnchorProcess } from './anchor';
import { DescendantCenterLayout as DescendantCenterLayoutProcess, HeirCenterLayout as HeirCenterLayoutProcess, StructuredLayout as StructuredLayoutProcess } from './layout';
import { Line as LineProcess } from './Line';
import { NodeValid as NodeValidProcess } from './node-valid';
import { Orientation as OrientationProcess } from './orientation';
import { Size as SizeProcess } from './size';
import { Visible as VisibleProcess } from './visible';
export declare namespace Process {
    type getRootHeirOrientationFunc = (id: string) => Mind.Orientation;
    interface EveryContext {
        /**
         * 当前处理节点缓存信息
         */
        cache: Mind.NodeCache;
    }
    interface StartContext {
        /**
         * 配置项
         */
        options: Required<Mind.Options>;
        /**
         * 根数据
         */
        root: Mind.Root;
        /**
         * 获取根直系子代的方位
         * @param id 直系子代 id
         */
        getRootHeirOrientation: getRootHeirOrientationFunc;
        /**
         * 缓存地图
         */
        cacheMap: Mind.CacheMap;
        /**
         * 上一次的缓存地图
         */
        preCacheMap?: Mind.CacheMap;
        /**
         * 可视窗口
         */
        viewport: HTMLElement;
        /**
         * 内容容器
         */
        container: HTMLElement;
        /**
         * 位移/缩放配置
         */
        transform: Mind.Transform;
        /**
         * 配置锚点
         */
        anchor?: string;
        /**
         * 位移/缩放控制器
         */
        zoom: Zoom;
    }
    interface Lifecycle<S = void, E = void, AE = void, END = void> {
        /**
         * 开始步骤
         */
        start?: (context: StartContext) => S;
        /**
         * 每一个节点处理（开始深度优先递归子代之前）
         * @param context 上下文环境
         */
        every?: (context: EveryContext) => E;
        /**
         * 每一个节点处理（结束深度优先递归子代之后）
         * @param context 上下文环境
         */
        afterEvery?: (context: EveryContext) => AE;
        /**
         * 结束处理步骤
         */
        end?: () => END;
    }
    const Size: typeof SizeProcess;
    const HeirCenterLayout: typeof HeirCenterLayoutProcess;
    const DescendantCenterLayout: typeof DescendantCenterLayoutProcess;
    const StructuredLayout: typeof StructuredLayoutProcess;
    const Visible: typeof VisibleProcess;
    const Line: typeof LineProcess;
    const Orientation: typeof OrientationProcess;
    const Anchor: typeof AnchorProcess;
    const NodeValid: typeof NodeValidProcess;
    const getLayoutProcess: (options: Required<Mind.Options>) => typeof HeirCenterLayoutProcess | typeof DescendantCenterLayoutProcess | typeof StructuredLayoutProcess | (new () => Mind.Process.Lifecycle);
}
