import { merge, throttle } from 'lodash';
import * as dagre from 'dagre';
import * as D3 from 'd3';
import Classnames from 'classnames';

const generateOptions=()=>({callback:{onNodeVisibleChange:e=>{},onTransformChange:e=>{}},childAlignMode:Mind.ChildAlignMode.structured,direction:Mind.Direction.x,event:{onViewportContextMenu:e=>{},onZoomEventTrigger:{end:e=>{},start:e=>{},zoom:e=>{}}},lineStyle:Mind.LinkStyle.bezier,nodeSeparate:50,rankSeparate:50,viewportPreloadPadding:0,zoomExtent:{},disableLinesTailor:!1}),generateCache=()=>({line:{source:{x:0,y:0},target:{x:0,y:0}},node:{},orientation:Mind.Orientation.root,processCache:{},rect:{height:0,width:0,x:0,y:0},visible:{lineAttachParent:!0,node:!0}}),generateTransform=()=>({scale:1,x:0,y:0}),withDefaultBuilder=e=>t=>t?merge(e(),t):e();const WithDefault={cache:withDefaultBuilder(generateCache),options:withDefaultBuilder(generateOptions),transform:withDefaultBuilder(generateTransform)};

const breadthFirstWalkTree=(e,r)=>{const t=e=>{const o=[];e.forEach((e=>{r.before(e)&&o.push(...e.children||[]);})),o.length&&t(o),r.after(e);};t([e]);};

const depthFirstWalkTree=(e,r)=>{const o=(e,t)=>{r.before(e,t)&&(e.children||[]).forEach((r=>o(r,e))),r.after(e,t);};o(e,void 0);};

const descendant=n=>{const c=[],e=(n=[])=>{for(const o of n)c.push(o),e(o.children);};return e(n.children),c};

const error=r=>new Error(`bade-mind: ${r}`);

const getLayoutCalcChildren=(i,e,r)=>{if(Helper.judgeIfAllChildFold(i,e))return [];const t=i.children||[];if(i.id!==e)return t;{const e=i.fold||[];return e[0]?t.filter((i=>r(i.id)===Mind.Orientation.positive)):e[1]?t.filter((i=>r(i.id)===Mind.Orientation.negative)):t}};

const withPrefix=i=>`mind__${i}`;

const getSvgPathId=i=>withPrefix(`line-${i}`);

const judgeIfAllChildFold=(l,o)=>l.id===o?!!l.fold&&Array.from(l.fold).length>0&&Array.from(l.fold).every((l=>l)):!!l.fold;

const judgeIfHeirAndFold=(i,d,n,e)=>{if((null==d?void 0:d.id)===n.node.id&&n.node.fold){if(n.node.fold[0]&&e(i.id)===Mind.Orientation.negative)return !0;if(n.node.fold[1]&&e(i.id)===Mind.Orientation.positive)return !0}return !1};

const judgeIfVisualLeaf=(e,f)=>!f||0===f.length||e.fold;

const rootToNodeArray=(o,e)=>{const r=[];e(o.node),r.push(o.node);let t=[...o.negative||[],...o.positive||[]];for(;t.length;){const o=[];t.forEach((o=>{e(o),r.push(o);})),t.forEach((e=>o.push(...e.children||[]))),t=o;}return r};

const transformRootToWalkable=t=>{const e=t.negative||[],i=t.positive||[],o=Object.assign({},t.node);o.children=[...e,...i];const n=new Map;return e.forEach((t=>n.set(t.id,Mind.Orientation.negative))),i.forEach((t=>n.set(t.id,Mind.Orientation.positive))),{getRootHeirOrientation:t=>n.get(t),shadowNode:o}};

const Helper={breadthFirstWalkTree:breadthFirstWalkTree,depthFirstWalkTree:depthFirstWalkTree,descendant:descendant,error:error,getLayoutCalcChildren:getLayoutCalcChildren,getSvgPathId:getSvgPathId,judgeIfAllChildFold:judgeIfAllChildFold,judgeIfHeirAndFold:judgeIfHeirAndFold,judgeIfVisualLeaf:judgeIfVisualLeaf,rootToNodeArray:rootToNodeArray,transformRootToWalkable:transformRootToWalkable,withPrefix:withPrefix};

class Anchor{constructor(){this.start=t=>{const{preCacheMap:s,cacheMap:r,anchor:e,transform:o,zoom:c,viewport:h,root:i}=t;this.anchor=e,this.cacheMap=r,this.transform=o,this.zoom=c,this.viewport=h,this.root=i,e&&s.get(e)&&(this.preAnchorRect=Object.assign({},s.get(e).rect));},this.end=()=>{const t=this.cacheMap.get(this.anchor||"");if(t&&this.preAnchorRect){const s={x:(t.rect.x-this.preAnchorRect.x)*this.transform.scale,y:(t.rect.y-this.preAnchorRect.y)*this.transform.scale};this.zoom.setTransform({scale:this.transform.scale,x:this.transform.x-s.x,y:this.transform.y-s.y});}else {const t=this.cacheMap.get(this.root.node.id);this.zoom.setTransform({scale:1,x:this.viewport.clientWidth/2-t.rect.x,y:this.viewport.clientHeight/2-t.rect.y});}};}}

const generateDagreGraphic=e=>{const r={[Mind.Direction.x]:"LR",[Mind.Direction.y]:"BT"},a=new dagre.graphlib.Graph;return a.setGraph({nodesep:e.nodeSeparate,rankdir:r[e.direction],ranker:"tight-tree",ranksep:e.rankSeparate}),a.setDefaultEdgeLabel((()=>({}))),a};

class DescendantCenterLayout{constructor(){this.start=e=>{const{options:t,cacheMap:o,root:i,getRootHeirOrientation:r}=e;this.root=i,this.options=t,this.cacheMap=o,this.getRootHeirOrientation=r;},this.afterEvery=e=>{const{cache:t}=e,{node:o}=t,i={height:t.rect.height,width:t.rect.width,x:0,y:0};t.processCache.descendantCenterLayout={localityRect:i};const r=Helper.getLayoutCalcChildren(o,this.root.node.id,this.getRootHeirOrientation);if(0===r.length)return i.x=t.rect.width/2,void(i.y=t.rect.height/2);const a=generateDagreGraphic(this.options);a.setNode(o.id,i),r.forEach((e=>{const t=this.cacheMap.get(e.id),i=t.processCache.descendantCenterLayout.localityRect,r={height:i.height,width:i.width,x:0,y:0};t.processCache.descendantCenterLayout.localityRectInParent=r,a.setNode(e.id,r),t.orientation===Mind.Orientation.positive?a.setEdge(o.id,e.id):a.setEdge(e.id,o.id);})),dagre.layout(a);const c=a.graph();i.width=c.width,i.height=c.height;},this.end=()=>{const e=this.cacheMap.get(this.root.node.id),t=e.node;e.layoutSize={height:e.processCache.descendantCenterLayout.localityRect.height,width:e.processCache.descendantCenterLayout.localityRect.width},Helper.breadthFirstWalkTree(t,{after:()=>{},before:e=>{const t=this.cacheMap.get(e.id);if(!t||Helper.judgeIfHeirAndFold(e,t.parent,this.root,this.getRootHeirOrientation))return !1;if(t.parent){const e=this.cacheMap.get(t.parent.id).processCache.descendantCenterLayout.origin,o=t.processCache.descendantCenterLayout.localityRectInParent,i=t.processCache.descendantCenterLayout.localityRect,r={x:e.x+o.x-o.width/2,y:e.y+o.y-o.height/2};t.processCache.descendantCenterLayout.origin=r,t.rect.x=i.x+r.x,t.rect.y=i.y+r.y,t.processCache.descendantCenterLayout.localityRectInParent=void 0,t.processCache.descendantCenterLayout.localityRect=void 0;}else t.rect.x=t.processCache.descendantCenterLayout.localityRect.x,t.rect.y=t.processCache.descendantCenterLayout.localityRect.y,t.processCache.descendantCenterLayout.origin={x:0,y:0};return !Helper.judgeIfAllChildFold(e,this.root.node.id)}});};}}

class HeirCenterLayout{constructor(){this.start=t=>{const{options:i,root:e,cacheMap:r}=t;this.root=e,this.cacheMap=r,this.options=i,this.graphic=generateDagreGraphic(i);},this.every=t=>{const{cache:i}=t,{node:e,parent:r}=i;this.graphic.setNode(e.id,i.rect),r&&(i.orientation===Mind.Orientation.positive?this.graphic.setEdge(r.id,e.id):this.graphic.setEdge(e.id,r.id));},this.end=()=>{dagre.layout(this.graphic);const t=this.cacheMap.get(this.root.node.id),i=this.graphic.graph();t.layoutSize={height:i.height,width:i.width};};}}

class DraggableLayout{}DraggableLayout.calcDragAttach=a=>{throw Helper.error("DraggableLayout static calcDragAttach must be implemented")},DraggableLayout.calcDropIndex=a=>{throw Helper.error("DraggableLayout static calcDropIndex must be implemented")},DraggableLayout.isValidExtendsClass=a=>a&&["calcDragAttach","calcDropIndex"].every((e=>a[e]));

const calcDragAttach=i=>{const{options:t,cacheMap:e,root:n,canBeAttachedNodes:o,draggingRect:r,ignoreNodes:d}=i,a=t.direction===Mind.Direction.y;let c=Mind.Orientation.root;const s=e.get(n.node.id).rect,h={x:0,y:0};if(a?(h.x=r.x,r.y+r.height/2<s.y-s.height/2?(c=Mind.Orientation.positive,h.y=r.y+r.height/2):r.y-r.height/2>s.y+s.height/2&&(c=Mind.Orientation.negative,h.y=r.y-r.height/2)):(h.y=r.y,r.x-r.width/2>s.x+s.width/2?(c=Mind.Orientation.positive,h.x=r.x-r.width/2):r.x+r.width/2<s.x-s.width/2&&(c=Mind.Orientation.negative,h.x=r.x+r.width/2)),c===Mind.Orientation.root)return;let y,x,u=1/0;for(const i of o){if(d.find((t=>t.id===i.id)))continue;const o=e.get(i.id);if(!o)continue;if(o.orientation!==Mind.Orientation.root&&o.orientation!==c)continue;const s=o.rect,f={x:0,y:0};if(a){if(f.x=s.x,c===Mind.Orientation.positive){if(f.y=s.y-s.height/2,f.y<h.y)continue}else if(f.y=s.y+s.height/2,f.y>h.y)continue}else if(f.y=s.y,c===Mind.Orientation.positive){if(f.x=s.x+s.width/2,f.x>h.x)continue}else if(f.x=s.x-s.width/2,f.x<h.x)continue;let g=o.processCache.structuredLayout.crossBoundary[0];n.node.id===i.id&&(g=c===Mind.Orientation.negative?o.processCache.structuredLayout.crossBoundary[0]:o.processCache.structuredLayout.crossBoundary[1]);const p=a?r.x:r.y;if(p<g.min-t.nodeSeparate/2||p>g.max+t.nodeSeparate/2)continue;const M=a?Math.abs(f.y-h.y):Math.abs(f.x-h.x);M<u&&(u=M,y=i,x=f);}if(x&&y){let i=y.children||[];if(y.id===n.node.id){const t=n.node.fold||[];i=t[1]||c!==Mind.Orientation.positive?t[0]||c!==Mind.Orientation.negative?[]:n.negative||[]:n.positive||[];}if(Helper.judgeIfVisualLeaf(y,i)&&u>2*t.rankSeparate)return;return {link:{source:x,target:h},node:y,orientation:c}}};

const calcDropIndex=i=>{const{attachedNodeChildren:t,dropPosition:d,options:e,cacheMap:n,dragNode:r,attachedNode:o}=i;if(!t||0===t.length||o.fold)return 0;const c=e.direction===Mind.Direction.y,h=c?d.x:d.y,l=i=>{const t=n.get(i).rect;return c?t.x:t.y};if(h<=l(t[0].id))return t[0].id===r.id?-1:0;if(h>=l(t[t.length-1].id))return t[t.length-1].id===r.id?-1:t.length;for(let i=1;i<t.length;i++)if(h>=l(t[i-1].id)&&h<=l(t[i].id))return t[i-1].id===r.id||t[i].id===r.id?-1:i;return -1};

const getNodeCrossBoundary=(e,t,r,a)=>{const c={max:1/0,min:-1/0},m={max:1/0,min:-1/0};return r?(m.min=e.rect.x-e.rect.width/2,m.max=e.rect.x+e.rect.width/2):(m.min=e.rect.y-e.rect.height/2,m.max=e.rect.y+e.rect.height/2),Helper.judgeIfVisualLeaf(e.node,t)?m:(c.min=Math.min(a.get(t[0].id).processCache.structuredLayout.crossBoundary[0].min,m.min),c.max=Math.max(a.get(t[t.length-1].id).processCache.structuredLayout.crossBoundary[0].max,m.max),c)};

class StructuredLayout extends DraggableLayout{constructor(){super(...arguments),this.start=t=>{const{options:e,cacheMap:i,root:o,getRootHeirOrientation:r}=t;this.root=o,this.options=e,this.cacheMap=i,this.getRootHeirOrientation=r;},this.afterEvery=t=>{const{cache:e}=t,{node:i}=e,o={height:e.rect.height,width:e.rect.width,x:0,y:0};e.processCache.structuredLayout={crossBoundary:[{max:1/0,min:-1/0},{max:1/0,min:-1/0}],localityRect:o};const r=Helper.getLayoutCalcChildren(i,this.root.node.id,this.getRootHeirOrientation);if(0===r.length)return o.x=e.rect.width/2,void(o.y=e.rect.height/2);const a={negative:0,positive:0},s={negative:0,positive:0},n=this.options.direction===Mind.Direction.y;r.forEach((t=>{const e=this.cacheMap.get(t.id),i=e.processCache.structuredLayout.localityRect,o={x:0,y:0};e.processCache.structuredLayout.inParentPosition=o,n?(e.orientation===Mind.Orientation.positive&&(i.height>a.positive&&(a.positive=i.height),o.x=s.positive+i.width/2,s.positive+=i.width+this.options.nodeSeparate),e.orientation===Mind.Orientation.negative&&(i.height>a.negative&&(a.negative=i.height),o.x=s.negative+i.width/2,s.negative+=i.width+this.options.nodeSeparate)):(e.orientation===Mind.Orientation.positive&&(i.width>a.positive&&(a.positive=i.width),o.y=s.positive+i.height/2,s.positive+=i.height+this.options.nodeSeparate),e.orientation===Mind.Orientation.negative&&(i.width>a.negative&&(a.negative=i.width),o.y=s.negative+i.height/2,s.negative+=i.height+this.options.nodeSeparate));})),s.positive&&(s.positive-=this.options.nodeSeparate),s.negative&&(s.negative-=this.options.nodeSeparate);const c=Math.max(s.positive,s.negative,n?e.rect.width:e.rect.height);a.positive&&a.negative?n?(o.y=a.positive+this.options.rankSeparate+e.rect.height/2,o.x=c/2,o.width=c,o.height=a.positive+a.negative+e.rect.height+2*this.options.rankSeparate):(o.x=a.negative+this.options.rankSeparate+e.rect.width/2,o.y=c/2,o.height=c,o.width=a.negative+a.positive+e.rect.width+2*this.options.rankSeparate):a.negative&&!a.positive?n?(o.y=e.rect.height/2,o.x=c/2,o.width=c,o.height=a.negative+e.rect.height+this.options.rankSeparate):(o.x=a.negative+this.options.rankSeparate+e.rect.width/2,o.y=c/2,o.height=c,o.width=a.negative+e.rect.width+this.options.rankSeparate):a.positive&&!a.negative&&(n?(o.y=a.positive+this.options.rankSeparate+e.rect.height/2,o.x=c/2,o.width=c,o.height=a.positive+e.rect.height+this.options.rankSeparate):(o.x=e.rect.width/2,o.y=c/2,o.height=c,o.width=a.positive+e.rect.width+this.options.rankSeparate));const h={negative:0,positive:0};n?(h.positive=o.x-s.positive/2,h.negative=o.x-s.negative/2):(h.positive=o.y-s.positive/2,h.negative=o.y-s.negative/2),r.forEach((t=>{const i=this.cacheMap.get(t.id),r=i.processCache.structuredLayout.inParentPosition,a=i.processCache.structuredLayout.localityRect;n?(i.orientation===Mind.Orientation.positive&&(r.y=o.y-e.rect.height/2-this.options.rankSeparate-a.height/2,r.x+=h.positive),i.orientation===Mind.Orientation.negative&&(r.y=o.y+e.rect.height/2+this.options.rankSeparate+a.height/2,r.x+=h.negative)):(i.orientation===Mind.Orientation.positive&&(r.x=o.x+e.rect.width/2+this.options.rankSeparate+a.width/2,r.y+=h.positive),i.orientation===Mind.Orientation.negative&&(r.x=o.x-e.rect.width/2-this.options.rankSeparate-a.width/2,r.y+=h.negative));}));},this.end=()=>{const t=this.cacheMap.get(this.root.node.id),e=t.node;t.layoutSize={height:t.processCache.structuredLayout.localityRect.height,width:t.processCache.structuredLayout.localityRect.width};const i=this.options.direction===Mind.Direction.y;Helper.breadthFirstWalkTree(e,{after:()=>{},before:t=>{const e=this.cacheMap.get(t.id);if(!e||Helper.judgeIfHeirAndFold(t,e.parent,this.root,this.getRootHeirOrientation))return !1;if(e.parent){const t=this.cacheMap.get(e.parent.id).processCache.structuredLayout.origin,i=e.processCache.structuredLayout.inParentPosition,o=e.processCache.structuredLayout.localityRect,r={x:t.x+i.x-o.width/2,y:t.y+i.y-o.height/2};e.processCache.structuredLayout.origin=r,e.rect.x=o.x+r.x,e.rect.y=o.y+r.y;}else e.rect.x=e.processCache.structuredLayout.localityRect.x,e.rect.y=e.processCache.structuredLayout.localityRect.y,e.processCache.structuredLayout.origin={x:0,y:0};const o=e.processCache.structuredLayout.crossBoundary;return i?(o[0].min=e.rect.x-e.processCache.structuredLayout.localityRect.width/2,o[0].max=e.rect.x+e.processCache.structuredLayout.localityRect.width/2):(o[0].min=e.rect.y-e.processCache.structuredLayout.localityRect.height/2,o[0].max=e.rect.y+e.processCache.structuredLayout.localityRect.height/2),e.processCache.structuredLayout.inParentPosition=void 0,e.processCache.structuredLayout.localityRect=void 0,!Helper.judgeIfAllChildFold(t,this.root.node.id)}}),t.processCache.structuredLayout.crossBoundary=[getNodeCrossBoundary(t,(e.fold||[])[0]?[]:this.root.negative,i,this.cacheMap),getNodeCrossBoundary(t,(e.fold||[])[1]?[]:this.root.positive,i,this.cacheMap)];};}}StructuredLayout.calcDragAttach=calcDragAttach,StructuredLayout.calcDropIndex=calcDropIndex;

class Line{constructor(){this.start=t=>{const{cacheMap:e,options:i,root:r,getRootHeirOrientation:o}=t;this.cacheMap=e,this.options=i,this.root=r,this.getRootHeirOrientation=o;},this.end=()=>{Helper.breadthFirstWalkTree(this.cacheMap.get(this.root.node.id).node,{after:()=>{},before:t=>{const e=this.cacheMap.get(t.id);if(!e||Helper.judgeIfHeirAndFold(t,e.parent,this.root,this.getRootHeirOrientation))return !1;if(e.parent){const t=this.cacheMap.get(e.parent.id);this.options.direction===Mind.Direction.x?(e.line.source.y=t.rect.y,e.line.target.y=e.rect.y,e.orientation===Mind.Orientation.positive?(e.line.source.x=t.rect.x+t.rect.width/2,e.line.target.x=e.rect.x-e.rect.width/2):(e.line.source.x=t.rect.x-t.rect.width/2,e.line.target.x=e.rect.x+e.rect.width/2)):(e.line.source.x=t.rect.x,e.line.target.x=e.rect.x,e.orientation===Mind.Orientation.positive?(e.line.source.y=t.rect.y-t.rect.height/2,e.line.target.y=e.rect.y+e.rect.height/2):(e.line.source.y=t.rect.y+t.rect.height/2,e.line.target.y=e.rect.y-e.rect.height/2));}return !Helper.judgeIfAllChildFold(t,this.root.node.id)}});};}}

class NodeValid{constructor(){this.start=o=>{const{root:e}=o;this.root=e;},this.every=o=>{const{cache:{node:e}}=o;if(!e.id)throw Helper.error("node id can not be empty or undefined");if(!e.sizeof)throw Helper.error("node sizeof function can not be undefined");if(this.root.node.id===e.id){if(void 0!==e.fold&&"object"!=typeof e.fold)throw Helper.error("root node fold should be undefined or array")}else if(void 0!==e.fold&&"boolean"!=typeof e.fold)throw Helper.error("normal node fold should be undefined or boolean")};}}

class Orientation{constructor(){this.start=t=>{const{root:i,getRootHeirOrientation:o,cacheMap:e}=t;this.root=i,this.getRootHeirOrientation=o,this.cacheMap=e;},this.every=t=>{const{cache:i}=t;i.parent?i.parent.id===this.root.node.id?i.orientation=this.getRootHeirOrientation(i.node.id):i.orientation=this.cacheMap.get(i.parent.id).orientation:i.orientation=Mind.Orientation.root;};}}

class Size{constructor(){this.every=e=>{const{cache:t}=e,c=t.node.sizeof();t.rect.width=c.width,t.rect.height=c.height;};}}

class Visible{constructor(){this.start=t=>{const{viewport:e,transform:i,root:o,cacheMap:r,options:n,getRootHeirOrientation:s}=t;this.viewport=e,this.transform=i,this.root=o,this.cacheMap=r,this.options=n,this.getRootHeirOrientation=s;},this.end=()=>{const t={lineAttachParent:!1,node:!1},e=this.viewport.clientHeight,i=this.viewport.clientWidth,o=(e+this.options.viewportPreloadPadding-this.transform.y)/this.transform.scale,r=(-this.options.viewportPreloadPadding-this.transform.x)/this.transform.scale,n=(i+this.options.viewportPreloadPadding-this.transform.x)/this.transform.scale,s=(-this.options.viewportPreloadPadding-this.transform.y)/this.transform.scale;return Helper.breadthFirstWalkTree(this.cacheMap.get(this.root.node.id).node,{after:()=>{},before:e=>{const i=this.cacheMap.get(e.id);if(!i||Helper.judgeIfHeirAndFold(e,i.parent,this.root,this.getRootHeirOrientation))return !1;const a=Object.assign({},i.visible);i.visible.node=!0,i.visible.lineAttachParent=!0;const h=i.rect;if((h.x-h.width/2>n||h.x+h.width/2<r||h.y-h.height/2>o||h.y+h.height/2<s)&&(i.visible.node=!1),i.parent){const t={bottom:Math.max(i.line.source.y,i.line.target.y),left:Math.min(i.line.source.x,i.line.target.x),right:Math.max(i.line.source.x,i.line.target.x),top:Math.min(i.line.source.y,i.line.target.y)};(t.left>n||t.right<r||t.bottom<s||t.top>o)&&(i.visible.lineAttachParent=!1);}return a.node!==i.visible.node&&(t.node=!0),a.lineAttachParent!==i.visible.lineAttachParent&&(t.lineAttachParent=!0),!Helper.judgeIfAllChildFold(e,this.root.node.id)}}),t};}}

var Process;!function(e){e.Size=Size,e.HeirCenterLayout=HeirCenterLayout,e.DescendantCenterLayout=DescendantCenterLayout,e.StructuredLayout=StructuredLayout,e.Visible=Visible,e.Line=Line,e.Orientation=Orientation,e.Anchor=Anchor,e.NodeValid=NodeValid,e.getLayoutProcess=e=>{const r={[Mind.ChildAlignMode.heirCenter]:HeirCenterLayout,[Mind.ChildAlignMode.descendantCenter]:DescendantCenterLayout,[Mind.ChildAlignMode.structured]:StructuredLayout};return e.layoutProcess?e.layoutProcess:r[e.childAlignMode]};}(Process||(Process={}));

const calcVisible=o=>{const{cacheMap:r,options:e,root:t,container:i,viewport:n,transform:s,zoom:a}=o,c=new Process.Visible,{getRootHeirOrientation:p}=Helper.transformRootToWalkable(t);return c.start({cacheMap:r,container:i,getRootHeirOrientation:p,options:e,root:t,transform:s,viewport:n,zoom:a}),c.end()};

const bezier=r=>{const{source:i,target:o,options:t}=r;return (t.direction===Mind.Direction.x?D3.linkHorizontal():D3.linkVertical())({source:[i.x,i.y],target:[o.x,o.y]})};

const line=x=>{const y=12,{source:e,target:i,options:n}=x,r={x:(e.x+i.x)/2,y:(e.y+i.y)/2};let t=[0,0],o=[0,0],l=[0,0],s=[0,0];if(n.direction===Mind.Direction.x){if(e.y===i.y)return D3.line()([[e.x,e.y],[i.x,i.y]]);t=[r.x,e.y],o=i.y>e.y?[r.x,i.y-y<e.y?e.y:i.y-y]:[r.x,i.y+y>e.y?e.y:i.y+y],s=i.x>e.x?[r.x+y>i.x?i.x:r.x+y,i.y]:[r.x-y<i.x?i.x:r.x-y,i.y],l=[o[0],s[1]];}else {if(e.x===i.x)return D3.line()([[e.x,e.y],[i.x,i.y]]);t=[e.x,r.y],o=i.x>e.x?[i.x-y<e.x?e.x:i.x-y,r.y]:[i.x+y>e.x?e.x:i.x+y,r.y],s=i.y>e.y?[i.x,r.y+y>i.y?i.y:r.y+y]:[i.x,r.y-y<i.y?i.y:r.y-y],l=[s[0],o[1]];}return D3.line()([[e.x,e.y],t,o])+D3.line().curve(D3.curveBasis)([o,l,s])+D3.line()([s,[i.x,i.y]])};

const getPathRender=e=>{const{pathRender:i,lineStyle:n}=e;if(i)return i;return {[Mind.LinkStyle.line]:line,[Mind.LinkStyle.bezier]:bezier}[n]};

const SvgClassName=Helper.withPrefix("lines");const GroupClassName=Helper.withPrefix("group");const PathClassName=Helper.withPrefix("line");const connect=e=>{const{cacheMap:t,options:a,root:s,container:i}=e,r=t.get(s.node.id),l=Array.from(t.values()).filter((e=>(e.visible.lineAttachParent||a.disableLinesTailor)&&e.node.id!==s.node.id)).map((e=>({node:e.node,source:e.line.source,target:e.line.target}))),o=D3.select(i);o.selectChild(`svg.${SvgClassName}`).empty()&&o.append("svg").attr("class",SvgClassName).append("g").attr("class",GroupClassName),o.selectChild(`svg.${SvgClassName}`).attr("viewBox",[0,0,r.layoutSize.width,r.layoutSize.height]).style("width",r.layoutSize.width).style("height",r.layoutSize.height).style("overflow","visible").style("position","relative").style("pointer-events","none").selectChild(`g.${GroupClassName}`).selectAll("path").data(l,(e=>e.node.id)).join("path").attr("id",(e=>Helper.getSvgPathId(e.node.id))).attr("d",(e=>{const s=Object.assign(Object.assign({},e),{cacheMap:t,options:a});return getPathRender(a)(s)})).attr("class",PathClassName).attr("fill","transparent");};

const layout=e=>{const{cacheMap:r,options:o,root:t,container:n,viewport:a,transform:c,anchor:s,zoom:i}=e,d=new Map(r);r.clear();const p=[new Process.NodeValid,new Process.Orientation,new Process.Size,new(Process.getLayoutProcess(o)),new Process.Line,new Process.Anchor],{shadowNode:f,getRootHeirOrientation:l}=Helper.transformRootToWalkable(t);p.forEach((e=>e.start&&e.start({anchor:s,cacheMap:r,container:n,getRootHeirOrientation:l,options:o,preCacheMap:d,root:t,transform:c,viewport:a,zoom:i}))),Helper.depthFirstWalkTree(f,{after:(e,o)=>{if(Helper.judgeIfHeirAndFold(e,o,t,l))return;const n={cache:r.get(e.id)};p.forEach((e=>e.afterEvery&&e.afterEvery(n)));},before:(e,o)=>{if(Helper.judgeIfHeirAndFold(e,o,t,l))return !1;const n=d.get(e.id)?Object.assign({},d.get(e.id)):WithDefault.cache();n.node=e,n.parent=o,r.set(e.id,n);const a={cache:n};return p.forEach((e=>e.every&&e.every(a))),!Helper.judgeIfAllChildFold(e,t.node.id)}}),p.forEach((e=>e.end&&e.end()));};

const Render={calcVisible:calcVisible,connect:connect,layout:layout};

class TemporaryLine{constructor(t,e,s){this.render=t=>{this.path.attr("d",t?getPathRender(this.options)({cacheMap:this.cacheMap,node:{},options:this.options,source:t.source,target:t.target}):null);},this.destroy=()=>{this.g.remove();},this.createPathElement=t=>{this.svg=D3.select(t).select(`.${SvgClassName}`),this.g=this.svg.append("g"),this.path=this.g.append("path"),this.path.attr("class",Classnames(PathClassName,withPrefix("temporary-line"))),this.path.attr("fill","transparent");},this.createPathElement(t),this.options=s,this.cacheMap=e;}}

class Drag{constructor(t){this.calcDropIndex=(t,o,e,r)=>this.draggableLayout.calcDropIndex({attachedNode:r,attachedNodeChildren:t,cacheMap:this.cacheMap,dragNode:e,dropPosition:o,options:this.options,root:this.root}),this.drag=(t,o)=>{const e=this.cacheMap.get(this.dragNode.id);if(!e||e.node.id===this.root.node.id)return;const r=this.draggableLayout.calcDragAttach({cacheMap:this.cacheMap,canBeAttachedNodes:o,draggingRect:Object.assign(Object.assign({},t),{height:e.rect.height,width:e.rect.width}),ignoreNodes:this.ignoreNodes,options:this.options,root:this.root});return r?(this.temporaryLine.render({source:r.link.source,target:r.link.target}),{attach:r.node,orientation:r.orientation}):void this.temporaryLine.render()},this.end=()=>{this.temporaryLine.destroy();};const{options:o,root:e,dragNode:r,cacheMap:a,container:i}=t;if(this.options=o,this.root=e,this.dragNode=r,this.cacheMap=a,this.container=i,this.draggableLayout=Process.getLayoutProcess(o),!DraggableLayout.isValidExtendsClass(this.draggableLayout))throw o.layoutProcess?Helper.error("The custom layoutProcess is not support drag action, it should extends DraggableLayout"):Helper.error(`The childAlignMode="${o.childAlignMode}" match layout process ${this.draggableLayout.name} is not support drag action`);this.ignoreNodes=[this.dragNode,...Helper.descendant(this.dragNode)],this.temporaryLine=new TemporaryLine(this.container,this.cacheMap,this.options);}}

const nodeTranslateTo=(e,t)=>{const{id:i,cacheMap:a,diff:r,relative:o,viewport:c,transform:d,zoom:l}=e,s=a.get(i);if(!s)throw Helper.error("id match is not exist or folded");{const e={height:c.clientHeight,width:c.clientWidth},i={x:0,y:0},a={x:s.rect.x*d.scale,y:s.rect.y*d.scale};switch(o.x){case Mind.RelativeX.left:i.x=0;break;case Mind.RelativeX.middle:i.x=e.width/2;break;case Mind.RelativeX.right:i.x=e.width;}switch(o.y){case Mind.RelativeY.top:i.y=0;break;case Mind.RelativeY.middle:i.y=e.height/2;break;case Mind.RelativeY.bottom:i.y=e.height;}l.setTransform({scale:d.scale,x:i.x-a.x+r.x,y:i.y-a.y+r.y},t);}};

class Zoom{constructor(t){this.controller=D3.zoom(),this.bind=(t,o)=>{const{start:e,zoom:s,end:r}=o;this.callback=t,this.event=o,D3.select(this.viewport).call(this.controller.on("zoom",(o=>{const e={scale:o.transform.k,x:o.transform.x,y:o.transform.y};t(e),s&&s(o.sourceEvent);})).on("start",(t=>e&&e(t.sourceEvent))).on("end",(t=>r&&r(t.sourceEvent)))).call(this.controller.transform,D3.zoomIdentity);},this.syncZoomExtent=t=>{this.controller.extent([[0,0],[t.width,t.height]]);},this.syncZoomExtentOptions=t=>{const{options:{zoomExtent:o}}=t;o.translate?this.controller.translateExtent(o.translate.map((t=>[t.x,t.y]))):this.controller.translateExtent([[-1/0,-1/0],[1/0,1/0]]),o.scale?this.controller.scaleExtent(o.scale):this.controller.scaleExtent([.5,2]);},this.scale=(t,o,e=0)=>{e?D3.select(this.viewport).transition().duration(e).call(this.controller.scaleTo,t,o&&[o.x,o.y]):D3.select(this.viewport).call(this.controller.scaleTo,t,o&&[o.x,o.y]);},this.translate=(t,o=0)=>{o?D3.select(this.viewport).transition().duration(o).call(this.controller.translateBy,t.x,t.y):D3.select(this.viewport).call(this.controller.translateBy,t.x,t.y);},this.setTransform=(t,o=0)=>{o?D3.select(this.viewport).transition().duration(o).call(this.controller.transform,new D3.ZoomTransform(t.scale,t.x,t.y)):D3.select(this.viewport).call(this.controller.transform,new D3.ZoomTransform(t.scale,t.x,t.y));},this.destroy=()=>{D3.select(this.viewport).on(".zoom",null).on(".start",null).on(".end",null);},this.viewport=t,this.controller.filter((t=>2===t.button||t.ctrlKey&&"wheel"===t.type));}}

class Graphic{constructor(t,i,o){this.cacheMap=new Map,this.transform=WithDefault.transform(),this.unbindCache=[],this.syncZoomExtentOptions=()=>{this.zoom.syncZoomExtentOptions({options:this.options});},this.getVisibleNodes=()=>{const t=[];for(const i of Array.from(this.cacheMap.values()))i.visible.node&&(this.root&&i.node.id===this.root.node.id?t.push(this.root.node):t.push(i.node));return t},this.getNodeAnchorCoordinate=t=>{const i=this.cacheMap.get(t);return i?{x:i.rect.x-i.rect.width/2,y:i.rect.y-i.rect.height/2}:void 0},this.bindEventListener=()=>{this.unbind();const t=t=>{this.options.event.onViewportContextMenu(t),t.preventDefault();};this.viewport.addEventListener("contextmenu",t),this.unbindCache.push((()=>{this.viewport.removeEventListener("contextmenu",t);})),this.zoom.bind(this.onTransform,{end:t=>this.options.event.onZoomEventTrigger.end(t),start:t=>this.options.event.onZoomEventTrigger.start(t),zoom:t=>this.options.event.onZoomEventTrigger.zoom(t)}),this.unbindCache.push(this.zoom.destroy),ResizeObserver&&(this.resizeObserver=new ResizeObserver(this.onViewportResize),this.resizeObserver.observe(this.viewport),this.unbindCache.push((()=>this.resizeObserver.unobserve(this.viewport))));},this.onTransform=t=>{this.transform=t,this.container.style.transform=`translateX(${t.x}px) translateY(${t.y}px) scale(${t.scale})`,this.container.style.transformOrigin="left top",this.refreshVisible(),this.options.callback.onTransformChange(t);},this.refreshVisible=()=>{if(this.cacheMap.size){const t=this.calcVisible();t.node&&this.options.callback.onNodeVisibleChange(this.getVisibleNodes()),t.lineAttachParent&&this.connect();}},this.throttleRefreshVisible=throttle(this.refreshVisible,100),this.onViewportResize=()=>{this.zoom.syncZoomExtent({height:this.viewport.clientHeight,width:this.viewport.clientWidth}),this.throttleRefreshVisible();},this.unbind=()=>{this.unbindCache.forEach((t=>t())),this.unbindCache=[];},this.judgeNodeVisible=t=>{const i=this.cacheMap.get(t);return !!i&&i.visible.node},this.setOptions=(t,i=!1)=>{this.options=i?merge({},this.options,t||{}):WithDefault.options(t),this.syncZoomExtentOptions();},this.dragControllerBuilder=t=>{var i;const o="string"==typeof t?null===(i=this.cacheMap.get(t))||void 0===i?void 0:i.node:t;return this.root&&o&&o.id!==this.root.node.id?new Drag({cacheMap:this.cacheMap,container:this.container,dragNode:o,options:this.options,root:this.root}):void 0},this.getLayoutSize=()=>{var t,i;const o=this.cacheMap.get((null===(i=null===(t=this.root)||void 0===t?void 0:t.node)||void 0===i?void 0:i.id)||"");return o?o.layoutSize:void 0},this.getNode=t=>{var i;return null===(i=this.cacheMap.get(t))||void 0===i?void 0:i.node},this.getParent=t=>{var i;return null===(i=this.cacheMap.get(t))||void 0===i?void 0:i.parent},this.getNodeOrientation=t=>{var i;return null===(i=this.cacheMap.get(t))||void 0===i?void 0:i.orientation},this.setTransform=(t,i)=>{this.transform=merge({},this.transform,t),this.zoom.setTransform(this.transform,i);},this.translate=(t,i)=>{this.zoom.translate(t,i);},this.scale=(t,i,o)=>{this.zoom.scale(t,i,o);},this.nodeTranslateTo=(t,i)=>{const{id:o,diff:e,relative:s}=t;nodeTranslateTo({cacheMap:this.cacheMap,diff:e,id:o,relative:s,transform:this.transform,viewport:this.viewport,zoom:this.zoom},i);},this.getTransform=()=>Object.assign({},this.transform),this.setAnchor=t=>{this.anchor=t;},this.setData=t=>{this.root=t,this.layout(),this.calcVisible(),this.connect(),this.syncLayoutSize(),this.options.callback.onNodeVisibleChange(this.getVisibleNodes());},this.refresh=()=>{this.root&&this.setData(this.root);},this.connectTo=t=>{Render.connect({cacheMap:this.cacheMap,container:t,options:this.options,root:this.root});},this.syncLayoutSize=()=>{var t,i;const o=(null===(i=this.cacheMap.get((null===(t=this.root)||void 0===t?void 0:t.node.id)||""))||void 0===i?void 0:i.layoutSize)||{height:0,width:0};this.container.style.width=`${o.width}px`,this.container.style.height=`${o.height}px`;},this.connect=()=>{this.connectTo(this.container);},this.layout=()=>{Render.layout({anchor:this.anchor,cacheMap:this.cacheMap,container:this.container,options:this.options,root:this.root,transform:this.transform,viewport:this.viewport,zoom:this.zoom});},this.calcVisible=()=>Render.calcVisible({cacheMap:this.cacheMap,container:this.container,options:this.options,root:this.root,transform:this.transform,viewport:this.viewport,zoom:this.zoom}),this.viewport=t,this.container=i,this.options=WithDefault.options(o),this.zoom=new Zoom(t),this.syncZoomExtentOptions(),this.bindEventListener();}}

var Mind;!function(e){e.ChildAlignMode={descendantCenter:"descendant-center",heirCenter:"heir-center",structured:"structured"},e.Orientation={negative:"negative",positive:"positive",root:"root"},e.Direction={x:"x",y:"y"},e.LinkStyle={bezier:"bezier",line:"line"},e.RelativeX={left:"left",middle:"middle",right:"right"},e.RelativeY={bottom:"bottom",middle:"middle",top:"top"},e.Graphic=Graphic,e.Drag=Drag,e.DraggableLayout=DraggableLayout,e._Helper=Helper,e._Process=Process,e._WithDefault=WithDefault;}(Mind||(Mind={}));

export { Mind };
